%%%---------------------------------------------------------------------%%%
%%%-------------------------Master Thesis 2015--------------------------%%%
%%%-----------------------------Mainscript------------------------------%%%
%%%------------------------Knut Vegard Lbergsli------------------------%%%
%%%-------------------Heat transfere during production------------------%%%
%%%------------------------Last updated 05.06.15------------------------%%%
%%%---------------------------------------------------------------------%%%

% Main function: Calculate the temperature distribution profile

% The scipt defines input variables from the trajectory (readed from excel)
% and the well design.
% Other input data is specified:
% - Geothermal gradient
% - Thermal properties
% - Reservoir fluid data, production rate and production time
% - Annulus fluid properties

% The script gives input data to the 5 different function, one for each
% case, and retrieves the results. 

%%%---------------------------------------------------------------------%%%

close all

%Read the general MD, TVD and Inclination form Excel
input=xlsread('DepthKV.xlsx','general');
%Flip matrix in input
B=flipud(input);

%Sorting parameters in Excel file
MD=B(:,1)/.3048;
TVD=B(:,2)/.3048;
INC=B(:,3);
%Horizontal inclination
HOR=90-INC;             

% %ft=in/12
% %ft=m/0.3048

%Defining shoe depth and top of cement for all sections. All given in ft.

%7in liner, 13Cr-110
shoe7=4052/.3048;
toc7=3600/0.3048;
%Assuming that the production tubing and the liner has same diameter.
%Tubing outside radius, ft
r_to=7/2/12;
%Thickness, ft
t_7=0.498/12;              
%Tubing inside radius, ft
r_ti=r_to-t_7;
%Radius of drill hole, ft
r_wb_7=8.5/2/12;

%9 5/8in casing, P-110
shoe958=3600/.3048;
toc958=2120/.3048;
%Casing outside radius,ft
r_co_9=(9+5/8)/2/12;
%Thickness, ft
t_9=0.545/12;              
%Casing inside radius, ft
r_ci_9=r_co_9-t_9;
%Radius of drill hole, ft
r_wb_9=12.25/2/12;

%13 3/8in casing, P-110
shoe1338=2120/.3048;
toc1338=327/.3048;
%Casing outside radius,ft
r_co_13=(13+3/8)/2/12;
%Thickness, ft
t_13=0.514/12;              
%Casing inside radius, ft
r_ci_13=r_co_13-t_13;
%Radius of drill hole, ft
r_wb_13=17.5/2/12;

%20in casing, X-56
shoe20=1000/.3048;
toc20=327/.3048;
%Casing outside radius,ft
r_co_20=20/2/12;
%Thickness, ft
t_20=0.635/12;              
%Casing inside radius, ft
r_ci_20=r_co_20-t_20;
%Radius of drill hole, ft
r_wb_20=26/2/12;

%30in casing, X-52
shoe30=420/.3048;
toc30=327/.3048;
%Casing outside radius,ft
r_co_30=30/2/12;
%Thickness, ft
t_30=1/12;              
%Casing inside radius, ft
r_ci_30=r_co_30-t_30;
%Radius of drill hole, ft
r_wb_30=36/2/12;

%Mudline = ml, ft
ml=327/0.3048;
%Mudline temp = ml_t, F
ml_T=39.2;

%Geothermal gradient, F/ft
g_T=0.0144;
%Matrix, same size as MD/TVD
T_geo=zeros(size(MD));
%Geothermal temperature (F) given by:
T_geo(:,1) = ml_T+(TVD(:,1)-ml)*g_T;

%Thermal properties of tubing, casing and formation.
%Thermal conductivity of formation from ILS, Btu/(hr-ft-F)
k_e=0.92;
%Thermal conductivity of tubing from ILS, Btu/(hr-ft-F)
k_tub=26.2;
%Emissitvity of outside tubing surface, dimensionless
e_to=0.9;
%Thermal conductivity of casing from ILS, Btu/(hr-ft-F)
k_csg=26.2;
%Emissitvity of outside casing surface (for all csg), dimensionless
e_co=0.9;  
%Emissitvity of inside casing surface (for all csg), dimensionless
e_ci=0.9;  
%Thermal conductivity of cement from ILS, Btu/(hr-ft-F)
k_cem=0.568;
%Thermal diffusivity of formation/earth, sq ft/hr
alpha=0.04;     %From Hasan and Kabir
%Stefan-Boltzmann constant, Btu/sq ft hr R
SB=1.713e-9;

%Production and reservoir fluid data:
%Assumed to produce "seawater"
%Production time, hr
t=2000;
%Reservoir temperature, F
T_res=T_geo;
%Total mas flow rate, lbm/sec (5000 m3/day)
W_sec=131.54;
%Total mas flow rate, lbm/hr
W=W_sec*3600;
%Heat capacity of wellbore fluid, Btu/lbm F
cp_f=3974.1/4186.8;                 %from [J/kg K] to [Btu/lbm F]

%Annulus A data - ref nr.1. Seawater in annulus.
%Density of annular fluid from Wellcat, lbm/cu ft
rho_an1=1031.1/16.01846;            %from [kg/m3] to [lbm/cu ft]
%Platic viscosity of annular fluid from Wellcat, lbm/ft hr
my_an1=1.089/0.4133788732138;       %from [cp] to [lbm/ft hr]
%Thermal conductivity of annular fluid, Btu/hr ft F 
k_an1=0.601/1.7307;                 %from [W/mK] to [Btu/hr ft F]
%Heat capasity of annular fluid, Btu/lbm F
cp_an1=3974.1/4186.8;               %from [J/kg K] to [Btu/lbm F]
    
%Annulus B data - ref nr.2 Seawater in annulus.
%Density of annular fluid from Wellcat, lbm/cu ft
rho_an2=1031.1/16.01846;            %from [kg/m3] to [lbm/cu ft]
%Platic viscosity of annular fluid from Wellcat, lbm/ft hr
my_an2=1.089/0.4133788732138;       %from [cp] to [lbm/ft hr]
%Thermal conductivity of annular fluid, Btu/hr ft F 
k_an2=0.601/1.7307;                 %from [W/mK] to [Btu/hr ft F]
%Heat capasity of annular fluid, Btu/lbm F
cp_an2=3974.1/4186.8;               %from [J/kg K] to [Btu/lbm F]

%Accelration due to gravity, ft/sec^2 
g=32.2;
%Conversion factor, lbm ft/lbf sq sec
g_c=32.2;
%Accelration due to gravity, ft/hr^2 
g_hr=32.2*3600.^2;
%Mechanical equivalent of heat, ft-lbf/Btu
J=778;

%Creating matrix of T_f and U_to with same size as MD/TVD
T_f = zeros(size(MD));
U_to = T_f;
T_co=zeros(size(MD));
T_wb=zeros(size(MD));

%Defining the first step for those variables were that is needed:
%First U_to - over-all heat transfer coefficient, Btu/hr sq ft F
U_to(1)=(r_to*log(r_to/r_ti)/k_tub + r_to*log(r_wb_7/r_to)/k_cem).^-1;
% %Assuming thermal conducitivty in tubing and casing is high;
% %T_ti=T_to
% %Neglecting resistance in the tubing.
% U_to(1)=(r_to*log(r_wb_7/r_to)/k_cem).^-1;    

%First T_f is assumed to be like the reservoir temp, F.
T_f(1)=T_res(1);

Counter=0;
for i=2:length(MD)
   %Case 1 
   if MD(i)<=shoe7 && MD(i)>=shoe958
        U_to(i)=U_to(1);       
        [T_f(i), T_wb(i)] = TUpred1(T_f(i-1),U_to(i),MD(i-1),MD(i),...
            T_geo(i-1),T_geo(i),alpha,t,r_wb_7,cp_f,W,k_e,r_to,g,...
            HOR(i),g_c,J,g_T);
   %Case 2
   elseif MD(i)<shoe958 && MD(i)>=shoe1338
        [U_to(i),  T_f(i), T_co(i), T_wb(i)] = TUpred2(T_f(i-1),...
            U_to(i-1),MD(i-1),MD(i),T_geo(i-1),T_geo(i),HOR(i),alpha,...
            t,r_wb_9,k_e,r_to,r_co_9,k_cem,r_ci_9,k_csg,cp_an1,my_an1,...
            k_an1,g_hr,rho_an1,k_tub,r_ti,e_to,e_ci,SB,cp_f,W,g,g_c,J,g_T);
   %Case 3
   elseif MD(i)<shoe1338 && MD(i)>=shoe20
        [U_to(i), T_f(i), T_co(i), T_wb(i)] = TUpred3(T_f(i-1),...
            U_to(i-1),MD(i-1),MD(i),T_geo(i-1),T_geo(i),HOR(i),...
            T_co(i-1),alpha,t,r_wb_13,r_to,k_e,r_co_13,k_cem,r_ci_13,...
            k_csg,r_co_9,e_co,e_ci,SB,cp_an2,my_an2,k_an2,rho_an2,g_hr,...
            e_to,r_ci_9,cp_an1,my_an1,k_an1,rho_an1,r_ti,g,g_c,J,cp_f,...
            g_T,k_tub,W);
   %Case 4
   elseif MD(i)<shoe20 & MD(i)>=shoe30
        [U_to(i), T_f(i), T_co(i), T_wb(i)] = TUpred4(T_f(i-1),...
            U_to(i-1),MD(i-1),MD(i),T_geo(i-1),T_geo(i),HOR(i),...
            T_co(i-1),alpha,t,r_wb_20,r_to,k_e,r_co_13,k_cem,r_ci_13,...
            k_csg,r_co_9,e_co,e_ci,SB,cp_an2,my_an2,k_an2,rho_an2,g_hr,...
            e_to,r_ci_9,cp_an1,my_an1,k_an1,rho_an1,r_ti,g,g_c,J,cp_f,...
            g_T,k_tub,W,r_co_20,r_ci_20);
   %Case 5     
   elseif MD(i)<shoe30 & MD(i)>=ml
       [U_to(i),  T_f(i), T_co(i), T_wb(i)] = TUpred5(T_f(i-1),...
           U_to(i-1),MD(i-1),MD(i),T_geo(i-1),T_geo(i),HOR(i),...
           T_co(i-1),alpha,t,r_wb_30,r_to,k_e,r_co_13,k_cem,r_ci_13,...
           k_csg,r_co_9,e_co,e_ci,SB,cp_an2,my_an2,k_an2,rho_an2,g_hr,...
           e_to,r_ci_9,cp_an1,my_an1,k_an1,rho_an1,r_ti,g,g_c,J,cp_f,...
           g_T,k_tub,W,r_co_20,r_ci_20,r_co_30,r_ci_30);
   end  
end



%Read "industry leading software" temperatures form Excel
input2=xlsread('WCtemp.xls');
%Flip matrix in input2
WC=flipud(input2);
%Sorting parameters
MD2=WC(:,1)/.3048;
T_f_wc=WC(:,2);
T_ti_wc=WC(:,3);

Tliste=zeros(length(T_f),2); Tliste(:,1)=MD*0.3048;Tliste(:,2)=T_f;...
    Tliste(:,3)=T_geo;Tliste(:,4)=T_co;Tliste(:,5)=T_wb;Tliste(:,6)=U_to;

%Read "force due to temperature" form Excel
input3=xlsread('DepthKV.xlsx','force');
%Flip matrix in input
force=flipud(input3);
%Sorting parameters
F_ML=force(:,1);
F_SC=force(:,2);
F_WC=WC(:,14);

