%%%---------------------------------------------------------------------%%%
%%%-------------------------Master Thesis 2015--------------------------%%%
%%%--------------------------------Case 1-------------------------------%%%
%%%------------------------Knut Vegard Lbergsli------------------------%%%
%%%---------------Calculation of wellbore fluid temperature-------------%%%
%%%------------------------Last updated 05.06.15------------------------%%%
%%%---------------------------------------------------------------------%%%

% TUpred1 calculates the fluid temperature in case nr.1

%%%---------------------------------------------------------------------%%%


function [T_f, T_wb_7] = TUpred1(T_prev,U_i,MD_prev,MD,T_g_prev,T_g,...
    alpha,t,r_wb_7,cp_f,W,k_e,r_to,g,hor,g_c,J,g_T)

%Where:
%T_prev=T_f(i-1)
%U_i=U_to(i)
%MD_prev=MD(i-1)
%MD=MD(i)
%T_g_prev=T_geo(i-1)
%T_g=T_geo(i)
%hor=HOR(i)

%Transient time function, dimensionless. Devloped by Ramey (1962)
% f_t=log(2*sqrt(alpha*t)/r_wb_7)-0.29;

%Tranisent time function, dimensionless. Developed by Hasan and Kabir
%(1994)
t_D=alpha*t/r_wb_7;

if t_D>=1e-10 && t_D<=1.5
    f_t=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
else
    f_t=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
end

%Temperature at cement-formation interface, F
T_wb_7=(T_prev*f_t + (k_e/(r_to*U_i)*T_g))/(f_t + (k_e/(r_to*U_i)));

%Inverse relaxation distance, ft
A=cp_f*W/(2*pi)*((k_e+(r_to*U_i*f_t))/(r_to*U_i*k_e));

%Temperature of flowing fluid, F
T_f=T_g + A*(1-exp((-MD_prev+MD)/A))*(-g*sin(degtorad(hor))/...
    (g_c*J*cp_f) + g_T*sin(degtorad(hor))) + exp((-MD_prev+MD)/A)*...
    (T_prev-T_g_prev);

end
    