%%%---------------------------------------------------------------------%%%
%%%-------------------------Master Thesis 2015--------------------------%%%
%%%--------------------------------Case 2-------------------------------%%%
%%%------------------------Knut Vegard Lbergsli------------------------%%%
%%%---------Calculation of the overall heat transfer coefficient--------%%%
%%%-----------------and the wellbore fluid temperature------------------%%%
%%%------------------------Last updated 05.06.15------------------------%%%
%%%---------------------------------------------------------------------%%%

% TUpred2 calculates the fluid temperature in case nr.2 by an iterative 
% process until convergence is obtained with the guessed and calculated
% U_to.

%%%---------------------------------------------------------------------%%%




function [U_new, T_new, T_co_9, T_wb_9] = TUpred2(T_prev,U_prev,...
    MD_prev,MD_i,T_g_prev,T_g,hor,alpha,t,r_wb_9,k_e,r_to,r_co_9,...
    k_cem,r_ci_9,k_csg,cp_an1,my_an1,k_an1,g_hr,rho_an1,k_tub,r_ti,...
    e_to,e_ci,SB,cp_f,W,g,g_c,J,g_T)

%Where:
%T_prev=T_f(i-1)
%T_new=T_f(i)
%U_prev=U_to(i-1)
%U_new=U_to(i)
%MD_prev=MD(i-1)
%MD_i=MD(i)
%T_g_prev=T_geo(i-1)
%T_g=T_geo(i))
%hor=HOR(i)

%Transient time function, dimensionless. Devloped by Ramey (1962)
% f_t=log(2*sqrt(alpha*t)/r_wb_9)-0.29;

%Tranisent time function, dimensionless. Developed by Hasan and Kabir
%(1994)
t_D=alpha*t/r_wb_9;

if t_D>=1e-10 && t_D<=1.5
    f_t=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
else
    f_t=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
end

    
run_while=2;
Counter2=0;

while run_while>1;
    Counter2=Counter2+1;
    %Temperature at cement-formation interface, F
    T_wb_9=(T_prev*f_t + (k_e/(r_to*U_prev)*T_g))/...
        (f_t + (k_e/(r_to*U_prev)));
    %Temperature outside of 9 5/8 casing surface, F 
    T_co_9=T_wb_9 + r_to*U_prev*(log(r_wb_9/r_co_9)/k_cem)*(T_prev-T_wb_9);
    %Temperature inside of 9 5/8 casing surface, F
    T_ci_9=T_co_9 + r_to*U_prev*log(r_co_9/r_ci_9)/k_csg*(T_prev-T_wb_9);
    
%     %Assuming thermal conducitivty in tubing and casing is high;
%     %T_ti=T_to and T_ci=T_co
%     %Temperature outside of 9 5/8 casing surface, F
%     T_co_9=T_wb_9+...
%          (r_to*U_prev*(log(r_wb_9/r_co_9)/k_cem)*(T_prev-T_wb_9));
%     %Temperature inside of 9 5/8 casing surface, F
%     T_ci_9=T_co_9;

    %View factor based on outside tubing and inside casing surfaces, 
    %dimensionless
    F_tci=1/((1/e_to)+((r_to/r_ci_9)*(1/e_ci-1)));
    %Heat transfer for radiation, Btu/hr sq ft F
    %Temperatures i Rankin (T(R)=T(F)+460)
    h_r=SB*F_tci*((T_prev+460).^2 + (T_ci_9+460).^2)*...
        ((T_prev+460) + (T_ci_9+460));
    
    %Temp in Annulus, F
    T_an=(T_prev+T_ci_9)/2;
    %Betta,temp in R
    betta=1/(T_an+460);     
    %Prandtl number, Pr, dim.less
    Pr=(cp_an1*my_an1)/k_an1;
    %Grashof number, Gr, dim.less
    Gr=((r_ci_9-r_to).^3*g_hr*rho_an1.^2*betta*abs(T_prev-T_ci_9))/...
        my_an1.^2;
    
    %Heat transfet for natrual convection, Btu/hr sq ft F
    h_c=((0.049*(Gr*Pr).^(1/3))*(Pr.^0.074)*k_an1)/(r_to*log(r_ci_9/r_to));
   
    %Over-all heat transfer coefficient, Btu/hr sq ft F
    U_new=1/(1/(h_c+h_r)+(r_to*log(r_wb_9/r_co_9))/k_cem+...
        (r_to*log(r_to/r_ti))/k_tub+(r_to*log(r_co_9/r_ci_9))/k_csg);
    
%     %For the assumption
%     %Over-all heat transfer coefficient, Btu/hr sq ft F
%     U_new=1/(1/(h_c+h_r)+(r_to*log(r_wb_9/r_co_9))/k_cem);
    
    %Margin of error in the iterative approach 
    if abs(U_new-U_prev)<1e-10
           %Inverse relaxation distance, ft
            A=cp_f*W/(2*pi)*((k_e+r_to*U_new*f_t)/(r_to*U_new*k_e));
           %Temperature of flowing fluid, F
            T_new =  T_g + A*(1-exp((-MD_prev+MD_i)/A))*...
                (-g*sin(degtorad(hor))/(g_c*J*cp_f) +...
                g_T*sin(degtorad(hor))) + exp((-MD_prev+MD_i)/A)*...
                (T_prev-T_g_prev);
        break
    else
        U_prev=U_new;
        
    end
    
end
disp(['Counter for case 2:' num2str(Counter2(end))]);
end

