%%%---------------------------------------------------------------------%%%
%%%-------------------------Master Thesis 2015--------------------------%%%
%%%--------------------------------Case 4-------------------------------%%%
%%%------------------------Knut Vegard Lbergsli------------------------%%%
%%%---------Calculation of the overall heat transfer coefficient--------%%%
%%%-----------------and the wellbore fluid temperature------------------%%%
%%%------------------------Last updated 05.06.15------------------------%%%
%%%---------------------------------------------------------------------%%%

% TUpred4 calculates the fluid temperature in case nr.2 by an iterative 
% process until convergence is obtained with the guessed and calculated
% U_to.

%%%---------------------------------------------------------------------%%%


function [U_new, T_new, T_co_new, T_wb_20] = TUpred4(T_prev,U_prev,...
    MD_prev,MD_i,T_g_prev,T_g,hor,T_co_prev,alpha,t,r_wb_20,r_to,...
    k_e,r_co_13,k_cem,r_ci_13,k_csg,r_co_9,e_co,e_ci,SB,cp_an2,my_an2,...
    k_an2,rho_an2,g_hr,e_to,r_ci_9,cp_an1,my_an1,k_an1,rho_an1,r_ti,...
    g,g_c,J,cp_f,g_T,k_tub,W,r_co_20,r_ci_20);

%Where:
%T_prev=T_f(i-1)
%T_new=T_f(i)
%U_prev=U_to(i-1)
%U_new=U_to(i)
%MD_prev=MD(i-1)
%MD_i=MD(i)
%T_g_prev=T_geo(i-1)
%T_g=T_geo(i))
%hor=HOR(i)
%T_co_new=T_co(i)
%T_co_pres=T_co(i-1)

%Transient time function, dimensionless. Devloped by Ramey (1962)
% f_t=log(2*sqrt(alpha*t)/r_wb_20)-0.29;

%Tranisent time function, dimensionless. Developed by Hasan and Kabir
%(1994)
t_D=alpha*t/r_wb_20;

if t_D>=1e-10 && t_D<=1.5
    f_t=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
else
    f_t=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
end


run_whilea=2;
run_whileb=2;
Counter4a=0;
Counter4b=0;
U_new=10;

while run_whilea>1;
    Counter4a=Counter4a+1;
    %Temperature at cement-formation interface, F
    T_wb_20=(T_prev*f_t + (k_e/(r_to*U_prev)*T_g))/...
        (f_t + (k_e/(r_to*U_prev)));
    %Temperature inside of 13 3/8 casing surface, F
    T_ci_13=T_wb_20 + (r_to*U_prev*(log(r_wb_20/r_co_20)/k_cem +...
        log(r_co_20/r_ci_20)/k_csg + log(r_ci_20/r_co_13)/k_cem +...
        log(r_co_13/r_ci_13)/k_csg)*(T_prev-T_wb_20));
    
%     %Assuming thermal conducitivty in tubing and casing is high;
%     %T_ti=T_to, T_ci_9=T_co_9, T_ci_13=T_co_13 and T_ci_20=T_co_20
%     T_ci_13=T_wb_20 + (r_to*U_prev*(log(r_wb_20/r_co_20)/k_cem +...
%             log(r_ci_20/r_co_13)/k_cem)*(T_prev-T_wb_20));
    
    
    %B Annulus calculations
    %View factor based on outside tubing and inside casing surfaces, 
    %dimensionless
    F_tci=1/((1/e_co)+((r_co_9/r_ci_13)*(1/e_ci-1)));
    %Heat transfer for radiation in B-annulus, Btu/hr sq ft F
    %Temperatures i Rankin (T(R)=T(F)+460)
    h_r2=SB*F_tci*((T_co_prev+460).^2+(T_ci_13+460).^2)*...
        ((T_co_prev+460)+(T_ci_13+460));
    
    %Temp in Annulus B, F
    T_an2=(T_co_prev+T_ci_13)/2;
    %Betta,temp in R
    betta2=1/(T_an2+460);     
    %Prandtl number, Pr, dim.less
    Pr2=(cp_an2*my_an2)/k_an2;
    %Grashof number, Gr, dim.less
    Gr2=((r_ci_13-r_co_9).^3*g_hr*rho_an2.^2*...
        betta2*abs(T_co_prev-T_ci_13))/my_an2.^2;
    %Heat transfet for natrual convection in B-annulus, Btu/hr sq ft F
    h_c2=((0.049*(Gr2*Pr2).^(1/3))*(Pr2.^0.074)*k_an2)/...
        (r_co_9*log(r_ci_13/r_co_9));
    
    %New temperature outside of 9 5/8 casing surface, F
    T_co_new=T_ci_13 + r_to*U_prev/(r_co_9*(h_r2+h_c2))*(T_prev-T_wb_20);
    
    %Margin of error in the iterative approach 
    if abs(T_co_new-T_co_prev)<1e-10
        while run_whileb>1;
            Counter4b=Counter4b+1;
            %Temperature inside of 9 5/8 casing surface, F
            T_ci_9=T_co_new + r_to*U_prev*log(r_co_9/r_ci_9)/...
                k_csg*(T_prev-T_wb_20);
            
%             %For the assumption
%             T_ci_9=T_co_new;
            
            %A annulus calculations
            %View factor based on outside tubing and inside casing surfaces, 
            %dimensionless
            F_tci=1/((1/e_to)+((r_to/r_ci_9)*(1/e_ci-1)));
            %Heat transfer for radiation in A-annulus, Btu/hr sq ft F
            %Temperatures i Rankin (T(R)=T(F)+460)
            h_r=SB*F_tci*((T_prev+460).^2+(T_ci_9+460).^2)*...
                ((T_prev+460)+(T_ci_9+460));
            
            %Temp in Annulus A, F
            T_an=(T_prev+T_ci_9)/2;
            %Betta,temp in R
            betta=1/(T_an+460);     
            %Prandtl number, Pr, dim.less
            Pr=(cp_an1*my_an1)/k_an1;
            %Grashof number, Gr, dim.less
            Gr=((r_ci_9-r_to).^3*g_hr*rho_an1.^2*...
                betta*abs(T_prev-T_ci_9))/my_an1.^2;
            %Heat transfet for natrual convection in A-annulus, Btu/hr sq ft F
            h_c=((0.049*(Gr*Pr).^(1/3))*(Pr.^0.074)*k_an1)/...
                (r_to*log(r_ci_9/r_to));
            
            %Over-all heat transfer coefficient, Btu/hr sq ft F
            U_new=1/(1/(h_c+h_r)+r_to/((h_c2+h_r2)*r_co_9) +...
                (r_to*log(r_wb_20/r_co_20))/k_cem +...
                (r_to*log(r_ci_20/r_co_13))/k_cem +...
                (r_to*log(r_co_20/r_ci_20))/k_csg +...
                (r_to*log(r_co_13/r_ci_13))/k_csg +...
                (r_to*log(r_co_9/r_ci_9))/k_csg +...
                (r_to*log(r_to/r_ti))/k_tub);
            
%             %For the assumption
%             %Over-all heat transfer coefficient, Btu/hr sq ft F
%             U_new=1/(1/(h_c+h_r)+r_to/((h_c2+h_r2)*r_co_9) +...
%                 (r_to*log(r_wb_20/r_co_20))/k_cem +...
%                 (r_to*log(r_ci_20/r_co_13))/k_cem);
            
            if abs(U_new-U_prev)<1e-10
                %Inverse relaxation distance, ft
                A=cp_f*W/(2*pi)*((k_e+r_to*U_new*f_t)/(r_to*U_new*k_e));
                %Temperature of flowing fluid, F
                T_new =  T_g + A*(1-exp((-MD_prev+MD_i)/A))*...
                    (-g*sin(degtorad(hor))/(g_c*J*cp_f) +...
                    g_T*sin(degtorad(hor))) + exp((-MD_prev+MD_i)/A)*...
                    (T_prev-T_g_prev); 
                break
            elseif  Counter4b==100
                    Counter4b=0;
                    break
            else
                U_prev=U_new;
            end
        end
            
    else
        T_co_prev=T_co_new;
    end

    if abs(T_co_new-T_co_prev)<1e-10 && abs(U_new-U_prev)<1e-10
        break
    end
end
disp(['Counter for case 4a:' num2str(Counter4a(end))]);
disp(['Counter for case 4b:' num2str(Counter4b(end))]);
end
