%%%---------------------------------------------------------------------%%%
%%%-------------------------Model Verification--------------------------%%%
%%%------------------------Last updated 11.05.15------------------------%%%
%%%---------------------------------------------------------------------%%%
%%%-------------------Testing Willhite's (1967) method------------------%%%
%%%---------------------------------------------------------------------%%%

%Steam at 600F is injected down 3 1/2in tubing set on a 9 5/8in packer,
%53.5 kb/ft, N-80 casing. The annulus contains a stagnant gas at 14.7 psia
%and the casing is cemented to surface in a 12in hole. A temperature survey
%in the well indicates a mean subsurface temperature of 100F. The reservoir
%is at 1,000 ft. 

%Estimate the over-all heat transfer coefficient, averange
%casing and wellbore heat loss after 21 days of continuous injection.

%Input data
r_to=0.146;     %ft
r_ci=0.355;     %ft
r_co=0.400;     %ft
r_wb=0.500;     %ft
alpha=0.0286;   %sq-ft/hr
k_e=1.0;        %Btu/hr sg ft F/ft
e_to=0.9;
e_ci=e_to;
k_cem=0.2;      %Btu/hr sg ft F/ft

SB=1.713e-9;    %Stefan-Boltzmann constant

t=21*24;    %Time in hr
T_geo=100;  %Geothermal temp, F
T_f=600;    %Steam injection temp

%Input to calculate h_c:
rho_an=0.0388;  %lb/cu ft
my_an=0.069;    %lb mass/ft hr
cp_an=0.245;    %Btu/lb F (Heat capasity of fluid in annulus)
k_ha=0.0255;    %Btu/hr sq ft F/ft (Thermal conductivity)
g=4.17e8;       %ft/hr^2 (Accelration due to gravity)

U_to=zeros(2,1);    %Make a matrix with zeros.
T_wb=zeros(size(U_to));

%Estimated U_to from Fig 3. / Guessed parameter
U_to(1)= 4.05;  %Btu/hr sg ft F/ft

for i=2:length(U_to)
    
    [U_to(i), T_wb(i)] = Uwillhite(U_to(i-1),r_wb,t,alpha,T_f,k_e,r_to,...
        T_geo,r_co,k_cem,e_to,r_ci,e_ci,SB,cp_an,my_an,k_ha,rho_an,g)
   
end

